@@ -15,16 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: wordlist.h 243664 2003-08-19 21:50:01Z gunnar $
+// $Id: wordlist.h 708922 2007-09-06 02:06:26Z amth $
 
 #ifndef WORDLIST_H
 #define WORDLIST_H
 
-#include <qxml.h>
-#include <qvaluestack.h>
-#include <qstring.h>
-#include <qobject.h>
-#include <qmap.h>
+#include <QtXml>
+#include <Qt3Support/Q3ValueStack>
+#include <QtCore/QObject>
+#include <QtCore/QMap>
+#include <QtCore/QTextStream>
 
 class QTextCodec;
 class KProgressDialog;
@@ -58,7 +58,7 @@ public:
    bool warning (const QXmlParseException &exception);
    bool error (const QXmlParseException &exception);
    bool fatalError (const QXmlParseException &exception);
-   QString errorString();
+   QString errorString() const;
  
    /** Processes the start of the document. */
    bool startDocument();
